//chemesis2.0
//cal8.g

//dimensions of compartments defined near the top for ease of changing
//probably these should go into parameter file
//e-4 is means that units are cm - this has to match the RA, RM units below
float somarad=2e-4
float somalen=1e-4
float dendrad=1e-4
float dendlen=2e-4

/* calcium specific parameters */
float DiffCa=6e-6       //cm^2/sec
float initCa=0.1e-3     //mM
float BufTot= 0.04      //mM
float initCaBuf= 0.005  //mM
int difshell=0
int difcyl=1

// HOW IS DIFFUSION AFFECTED BY COMPARTMENT SIZE - change dendcomps
int dendcomps=2
int i
//HOW IS DIFFUSION AFFECTED BY HAVING SOMA SHELLS?
int somashells=2

//parameters for electrical aspects
//all units are SI but length, to work with
float RA = 100  /* ohm-cm, could be 200 */
float RM = 0.01e6    /* ohms - cm^2; 5e-2 from Spruston et al */
float CM = 1e-6     /* Farads/cm^2; from Spruston et al. */
//these units result in time units = sec
float PI=3.14159
//currents through GHK need to be ~1e6x smaller than without GHK
float PCaT=0.005e-6

//function to create rxnpools of calcium, buffer and bimolecular reaction
include cabufdiff.g
//function to create compartment
include compSI.g
//function to create calcium channel
include icaTab.g

//----------------start the model here------------------------
//neutral element which acts as directory, to organize elements
create neutral cell
ce cell

//invoke function to create rxnpools and reaction
    float height={somarad/somashells}
    float outerrad, innerrad
    outerrad=somarad
    innerrad=somarad-height
    for (i=1; i<=somashells; i=i+1)
        cabuf soma {i} {initCa} {initCaBuf} {BufTot} {outerrad} {somalen} {innerrad}
        outerrad=innerrad
        innerrad=innerrad-height
        if (i == {somashells-1})
           innerrad=0.0
        end
    end 
    for (i=1; i<=dendcomps; i=i+1)
        cabuf dend {i} {initCa} {initCaBuf} {BufTot} {dendrad} {dendlen/dendcomps} 0 
    end

//create diffusion element which allows movement of Ca between compartments.
// diffusion between shells uses different surface area than for dendrite
   for (i=1; i<somashells; i=i+1)
        Diffusion somaCa[{i}] somaCa[{i+1}] {DiffCa} somadiff[{i}] {difshell}
    end

    Diffusion somaCa[{somashells}] dendCa[1] {DiffCa} somadend {difcyl}

    for (i=1; i<dendcomps; i=i+1)
        Diffusion dendCa[{i}] dendCa[{i+1}] {DiffCa} denddiff[{i}] {difcyl}
    end

    create conservepool caext
    setfield caext Ctot 2 volume 1 Cinit 2

//*********create electrical cell compartment***********
    make_comp soma {somalen} {somarad}
    make_comp dendrite {dendlen} {dendrad}
    addmsg dendrite soma RAXIAL Ra previous_state
    addmsg soma dendrite AXIAL  previous_state

//add calcium channels, use SI units else ghk won't work
   float Actvhalf=-30e-3
   float Actslope=-10e-3
   float Acttau=5.0e-3
   float Inactvhalf=-49e-3
   float Inactslope=6e-3
   float Inacttau=75e-3
   make_ica_ghk soma somaCa[1] caext "CaT" {PCaT} {Actvhalf} {Actslope} {Acttau} {Inactvhalf} {Inactslope} {Inacttau}
//consider making this channel in the library and copy into both compartments

// Iunits of 1 indicates Amps, but -1 should convert from modeler to physiologists convention
   setfield somaCa[1] Iunits -1
    for (i=1; i<=dendcomps; i=i+1)
        setfield dendCa[{i}] Iunits -1
    end
//setup graphs to display results
include cal8graph.g

//again, use a larger dt for output
setclock 0 0.000001
setclock 1 0.0001

reset
step 100000
setfield soma inject 0.01e-9
step 10000
setfield soma inject 0
step 90000
step 800000
setfield /graph1/# xmax 1
step 1000000
setfield /graph1/# xmax 2
step 1000000
setfield /graph1/# xmax 3

/*Notice that calcium and calcium bound buffer continues to increase
 in the soma.  There are no pumps in this model, thus nothing to restore
the total calcium to its original level.  
Also, though the channel inactivates, it is not completely inactivated.
No potassium currents restore membrane potential to rest.
Some calcium continues to flow in.*/
